Task: WikiMovies
=================
Description: Closed-domain QA dataset asking templated questions about movies, answerable from Wikipedia. From Miller et al. '16. 

Link: https://arxiv.org/abs/1606.03126

Tags: #WikiMovies, #All, #QA

